
option loqo_options "outlev=2";
option snopt_options "outlev=2";
option kestrel_options "solver=loqo";

option solver kestrel;

model;
include mountain.mod;

data;

###############################################################################
# Select parameters for the elastic string algorithm
###############################################################################
include mountain.dat;

###############################################################################
# Select the domain on which the problem will be solved
###############################################################################
#include domain/annulus.dat;
include domain/circle.dat;
#include domain/circle_rec.dat;
#include domain/lshaped.dat;
#include domain/rectangle.dat;

###############################################################################
# Select the equation to solve
###############################################################################
#include equation/henon.dat;
include equation/lane_emden.dat;
#include equation/perturbed.dat;

###############################################################################
# Calculate an ending point on the other side of the barrier
###############################################################################
problem p1;
param EBAR;
param BBAR;
param UBAR {N};

for {iter in 1..10} {
  let {b1 in 0..BREAK+1, n in N} u[b1,n] := 
    (1 - b1/(BREAK+1))*US[n] + (b1/(BREAK+1))*UE[n];

  if (energy[BREAK+1] < 0) then break;
  let {n in N} UE[n] := 2*UE[n];
}

###############################################################################
# Backtrack to the barrier to get a better representation
###############################################################################
let {n in N} UBAR[n] := US[n];
for {iter in 1..10} {
  let {b1 in 0..BREAK+1, n in N} u[b1,n] := 
    (1 - b1/(BREAK+1))*UBAR[n] + (b1/(BREAK+1))*UE[n];

  let EBAR := max{b1 in 0..BREAK+1 : energy[b1] < 0.0} energy[b1];
  let BBAR := min{b1 in 0..BREAK+1 : energy[b1] = EBAR} b1;
  let {n in N} UBAR[n] := u[BBAR-1, n];
  let {n in N} UE[n] := u[BBAR, n];
}

###############################################################################
# Elastic string for varying break points
###############################################################################

for {iter in 10..30 by 5} {
  let BREAK := iter;

  #############################################################################
  # Set the starting point for the elastic string algorithm and solve model
  #############################################################################
  problem p1;
  let {b1 in 0..BREAK+1, n in N} u[b1,n] := 
    (1 - b1/(BREAK+1))*US[n] + (b1/(BREAK+1))*UE[n];
  let z := max{b1 in 0..BREAK+1} energy[b1];

  solve;

  #############################################################################
  # Output data necessary for postprocessing
  #############################################################################

  printf {n in N}: "%5.4e %5.4e %d\n", 
    COORDS[n,1], COORDS[n,2], BNDRY[n] > ("output_" & iter & "/coords.dat");
  printf {e in E}: "%d %d %d\n", 
    TRIANG[e,1], TRIANG[e,2], TRIANG[e,3] > ("output_" & iter & "/elem.dat");
  printf {b1 in 0..BREAK+1, n in N}: "%5.4e\n", 
    u[b1,n] > ("output_" & iter & "/points.dat");
  
  problem p2;
  option presolve 0;
  write ("boutput_" & iter & "/matf");
}

